@@ -2,7 +2,7 @@ package Term::Table::LineBreak;
 use strict;
 use warnings;
 
-our $VERSION = '0.005';
+our $VERSION = '0.011';
 
 use Carp qw/croak/;
 use Scalar::Util qw/blessed/;
@@ -27,7 +27,6 @@ sub break {
     $self->{+IDX} = 0;
     my $str = $self->{+STRING} . ""; # Force stringification
 
-    binmode(STDOUT, ':utf8');
     my @parts;
     my @chars = split //, $str;
     while (@chars) {
@@ -40,10 +39,7 @@ sub break {
             my $l = uni_length("$char");
             last unless $l;
 
-            if ($char eq "\n") {
-                last;
-                next;
-            }
+            last if $char eq "\n";
 
             if ($size + $l > $len) {
                 unshift @chars => $char;
@@ -53,6 +49,10 @@ sub break {
             $size += $l;
             $part .= $char;
         }
+
+        # If we stopped just before a newline, grab it
+        shift @chars if $size == $len && @chars && $chars[0] eq "\n";
+
         until ($size == $len) {
             $part .= ' ';
             $size += 1;
